@@ -26,22 +26,37 @@ test_that("tidy.glm works", {
     expect_equal(td2$term, c("(Intercept)", "wt", "disp"))
 })
 
-test_that("tidy.anova and tidy.aov work", {
+test_that("tidy.anova, tidy.aov, and tidy.aovlist work", {
     anovafit = anova(lm(mpg ~ wt + disp, mtcars))
     td = tidy(anovafit)
     check_tidy(td, exp.row=3, exp.col=6)
     expect_true("Residuals" %in% td$term)
     
     aovfit = aov(mpg ~ wt + disp, mtcars)
-    td = tidy(anovafit)
+    td = tidy(aovfit)
     check_tidy(td, exp.row=3, exp.col=6)
     expect_true("Residuals" %in% td$term)
+    
+    aovlistfit = aov(mpg ~ wt + disp + Error(drat), mtcars)
+    td = suppressWarnings(tidy(aovlistfit))
+    check_tidy(td, exp.row=3, exp.col=7)
+    expect_true("Residuals" %in% td$term)
+})
+
+test_that("tidy.anova warns unknown column names when comparing two loess", {
+    loessfit <- anova(
+        loess(dist ~ speed, cars),
+        loess(dist ~ speed, cars, control = loess.control(surface = "direct"))
+    )
+    expect_warning(tidy(loessfit))
 })
 
 test_that("tidy.nls works", {
-    nlsfit = nls(wt ~ a + b * mpg + c / disp, data=mtcars, start=list(a=1, b=2, c=3))
+    nlsfit = nls(wt ~ a + b * mpg + c / disp,
+                 data = mtcars,
+                 start = list(a = 1, b = 2, c = 3))
     td = tidy(nlsfit)
-    check_tidy(td, exp.row=3, exp.col=5)
+    check_tidy(td, exp.row = 3, exp.col = 5)
     expect_equal(td$term, c("a", "b", "c"))
 })
 
@@ -96,9 +111,12 @@ test_that("tidy.htest works on wilcoxon tests", {
     check_tidy(td, exp.row=1, exp.names=n)
 })
 
+
+context("tidying summaries")
+
 test_that("tidy.summary works (even with NAs)", {
     df <- data.frame(group = c(rep('M', 6), 'F', 'F', 'M', 'M', 'F', 'F'),
-                 val = c(6, 5, NA, NA, 6, 13, NA, 8, 10, 7, 14, 6))
+                     val = c(6, 5, NA, NA, 6, 13, NA, 8, 10, 7, 14, 6))
     
     td <- tidy(summary(df$val))
     expect_is(td, "data.frame")
@@ -110,4 +128,21 @@ test_that("tidy.summary works (even with NAs)", {
     expect_equal(td$q3, 10)
     expect_equal(td$maximum, 14)
     expect_equal(td$na, 3)
+    
+    gl <- glance(summary(df$val)) # same as td
+    expect_identical(td, gl)
+})
+
+
+context("NULL and default tidy")
+
+test_that("tidy.NULL returns empty data frame", {
+    td <- tidy(NULL)
+    expect_is(td, "data.frame")
+    check_tidy(td, exp.row = 0, exp.col = 0)
+})
+
+test_that("tidy.default throws warning before turning into data.frame", {
+    expect_warning(td <- tidy(raw(1)))
+    check_tidy(td, exp.row = 1, exp.col = 1)
 })
